@@ -5,7 +5,6 @@ from typing import List, Generator
 import pytest
 from sqlalchemy import insert, select, update, delete
 from sqlalchemy.orm import Session
-
 from tests.conftest import sync_db as db, Base, User
 
 
@@ -111,6 +110,10 @@ def test_save(fake_users):
     db.save(user2)
     u = db.scalar(select(User).where(User.username == 'new_user2'))
     assert u.username == 'new_user2'
+    # test refresh
+    user3 = User(username='new_user3')
+    db.save(user3, refresh=True)
+    assert user3.id
 
 
 def test_run_sync(fake_users):
